@@ -3,6 +3,12 @@ from fly_python_sdk.fly.org import Org
 
 
 class Fly(FlyApi):
+    def __init__(
+        self,
+        api_token: str,
+    ):
+        super().__init__(api_token)
+
     def Org(
         self,
         org_slug: str = "personal",
